/**
 * @file
 * Contains the definition of the OpenAgenda filters behaviour.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.openAgendaFilters = {
    attach: function (context) {
      // Load only once.
      if (context !== document) {
        return;
      }

      const ajaxUrl = drupalSettings.openagenda.ajaxUrl;
      const filtersUrl = drupalSettings.openagenda.filtersUrl;
      const agenda = document.querySelector('.oa-agenda');

      // window.oa.
      if (typeof window.oa === 'undefined') {
        window.oa = {
          query: window.location.search,
          locale: drupalSettings.openagenda.lang,
          locales: {
            en: {
              eventsTotal: '{total, plural, =0 {No events match this search} one {{total} event} other {{total} events}}'
            },
            fr: {
              eventsTotal: '{total, plural, =0 {Aucun événement ne correspond à cette recherche} one {{total} événement} other {{total} événements}}'
            }
          },
          res: drupalSettings.openagenda.filtersUrl,
          filtersRef: null,
          values: null,
          queryParams: null,
          onLoad: async (values, aggregations, filtersRef, _form) => {
            oa.filtersRef = filtersRef;
            oa.values = values;
            const queryParams = {...values, aggregations};
            oa.queryParams = queryParams;

            // Update filters and widgets.
            oa.updateFiltersAndWidgets()
          },
          onFilterChange: async (values, aggregations, filtersRef, _form) => {
            oa.filtersRef = filtersRef;
            oa.values = values;
            const queryParams = {...values, aggregations};
            oa.queryParams = queryParams;

            // Show Ajax Throbber, automatically removed when content is replaced/page reloaded.
            $('#oa-wrapper').append(Drupal.theme.ajaxProgressIndicatorFullscreen());

            // Load event then update filters.
            Drupal.ajax({
              url: ajaxUrl + '?' + $.param(oa.queryParams)
            }).execute();
          },
          updateFiltersAndWidgets: async () => {
            // Update location, filters & widgets.
            if (!oa.filtersRef) {
              return;
            }
            $.ajax({
              url: filtersUrl + '?' + $.param(oa.queryParams),
              type: 'GET',
              dataType: 'json',
              async: false,
              complete: (data) => {
                oa.filtersRef.updateFiltersAndWidgets(oa.values, data.responseJSON);
                oa.filtersRef.updateLocation(oa.values);
              }
            });
          }
        };
      }

      const observer = new MutationObserver((mutations, observer) => {
        oa.updateFiltersAndWidgets(null, null, null);
      });
      observer.observe(agenda, {
        subtree: true,
        attributes: true,
      });

    }
  };
})(jQuery, Drupal, drupalSettings);
